package sequoia;

import java.sql.Connection;
import java.sql.SQLException;
import javax.naming.InitialContext;
import javax.sql.DataSource;

/**
 * Manages <pre>Connection</pre> creation and disposal
 * backed by <a href="http://jakarta.apache.org/commons/dbcp">DBCP</a>
 * connection pooling engine.
 */
public class PooledConnectionFactory extends ConnectionFactory {
  protected static InitialContext initContext;
  protected DataSource dataSource;

  protected String dataSourceJndi = "java:comp/env/jdbc/DB2-vyucba";

  public PooledConnectionFactory() {
    try {
    initContext = new InitialContext();
    if(initContext == null)
      throw new Error("Failed to retrieve InitialContext");

    dataSource = (DataSource) initContext.lookup(dataSourceJndi);
    if(dataSource == null)
      throw new Error("Failed to get datasource for DB2-vyucba");
    } catch (javax.naming.NamingException e) {
      throw new Error("Failed to retrieve InitialContext", e);
    }
  }

  public Connection connect() throws SQLException {
    return dataSource.getConnection();
  }
  public void disconnect(Connection c) throws SQLException {
    c.close();
    c = null;
  }
}