package sequoia.tags;

import javax.servlet.jsp.JspException;

/**
 * Recodes variable from PageContext from ISO-8859-1 to user-specified
 * encoding.
 */
public class RecodeVariableTag extends javax.servlet.jsp.tagext.TagSupport {
  /**
   * Attribute "var" value.
  */
  protected String var;
  /**
   * Default character encoding.
  */
  protected String encoding = "utf-8";

  /**
   * Handler, when "var" attribute is set.
  */
  public void setVar(String var) {
    this.var = var;
  }

  /**
   * Handler, when "encoding" attribute is set.
  */
  public void setEncoding(String encoding) {
    this.encoding = encoding;
  }

  /**
   * Recodes string from ISO-8859-1 encoding to user specified encoding.
   * Recoding is made using String(string, string) constructor.
  */
  private String recode(String string, String encoding) throws java.io.UnsupportedEncodingException {
    if(string != null) {
      return new String(string.getBytes("ISO-8859-1"), encoding);
    } else {
      return "";
    }
  }

  /**
   * Performs recoding of variable in attribute <code>var</code> from
   * ISO-8859-1 to encoding specified in <code>encoding</code>.
   * Variable is taken from the PageContext, cast to String
   * and saved back to PageContext.
  */
  public int doStartTag() throws JspException {
    try {
      Object o = pageContext.getAttribute(var);
      if (o instanceof String) {
        String s = (String) o;
        pageContext.setAttribute(var, recode(s, encoding));
      }
      return SKIP_BODY;
    } catch (Exception e) {
      throw new JspException(e);
    }
  }
}